enableLocation abstract method
Enables location.
On Android, opens the location settings screen and toggles the location switch to enable location. If the location already enabled, it does nothing.
Implementation
Future<void> enableLocation();
Enables location.
On Android, opens the location settings screen and toggles the location switch to enable location. If the location already enabled, it does nothing.
Future<void> enableLocation();