enterText abstract method

Future<void> enterText(
  1. AndroidSelector selector, {
  2. required String text,
  3. KeyboardBehavior? keyboardBehavior,
  4. Duration? timeout,
  5. Offset? tapLocation,
})

Enters text to the native view specified by selector.

If the text field isn't immediately visible, this method waits for the view to become visible. It prioritizes the timeout duration provided in the method call. If timeout is not specified, it utilizes the AndroidAutomatorConfig.findTimeout duration from the configuration.

The native view specified by selector must be:

  • EditText on Android
  • TextField or SecureTextField on iOS

See also:

Implementation

Future<void> enterText(
  AndroidSelector selector, {
  required String text,
  KeyboardBehavior? keyboardBehavior,
  Duration? timeout,
  Offset? tapLocation,
});