getNativeViews abstract method

Returns a list of currently visible native UI controls, specified by selector, which are currently visible on screen.

If selector is null, returns the whole native UI tree.

Implementation

Future<AndroidGetNativeViewsResponse> getNativeViews(
  AndroidSelector? selector,
);