getNotifications abstract method
Returns notifications that are visible in the notification shade.
Notification shade has to be opened with openNotifications.
Implementation
Future<List<Notification>> getNotifications();
Returns notifications that are visible in the notification shade.
Notification shade has to be opened with openNotifications.
Future<List<Notification>> getNotifications();