openQuickSettings abstract method

Future<void> openQuickSettings()
inherited

Opens the quick settings shade on Android and Control Center on iOS.

Doesn't work on iOS Simulator because Control Center is not available there.

See also:

Implementation

Future<void> openQuickSettings();