takeCameraPhoto abstract method

Future<void> takeCameraPhoto({
  1. AndroidSelector? shutterButtonSelector,
  2. AndroidSelector? doneButtonSelector,
  3. Duration? timeout,
})

Take and confirm the photo

This method taps on the camera shutter button to take a photo, then taps on the confirmation button to accept it.

You can provide custom selectors for both the shutter and confirmation buttons using shutterButtonSelector and doneButtonSelector parameters. If no custom selectors are provided, default selectors will be used.

For different camera apps or device manufacturers, you may need to provide custom selectors with the appropriate resource identifiers for your specific app.

Implementation

Future<void> takeCameraPhoto({
  AndroidSelector? shutterButtonSelector,
  AndroidSelector? doneButtonSelector,
  Duration? timeout,
});