tapOnNotificationBySelector abstract method

Future<void> tapOnNotificationBySelector(
  1. AndroidSelector selector, {
  2. Duration? timeout,
})

Taps on the visible notification using selector.

If the notification is not visible immediately, this method waits for the notification to become visible for timeout duration. If timeout is not specified, it utilizes the AndroidAutomatorConfig.findTimeout duration from the configuration.

Notification shade has to be opened first with openNotifications.

On iOS, only IOSSelector.titleContains is taken into account.

See also:

Implementation

Future<void> tapOnNotificationBySelector(
  AndroidSelector selector, {
  Duration? timeout,
});