waitUntilVisible abstract method

Future<void> waitUntilVisible(
  1. AndroidSelector selector, {
  2. Duration? timeout,
})

Waits until the native view specified by selector becomes visible. It waits for the view to become visible for timeout duration. If timeout is not specified, it utilizes the AndroidAutomatorConfig.findTimeout.

Implementation

Future<void> waitUntilVisible(AndroidSelector selector, {Duration? timeout});