AndroidSelector class

An Android-specific selector for finding UI elements.

Implemented types

Constructors

AndroidSelector({String? className, bool? isCheckable, bool? isChecked, bool? isClickable, bool? isEnabled, bool? isFocusable, bool? isFocused, bool? isLongClickable, bool? isScrollable, bool? isSelected, String? applicationPackage, String? contentDescription, String? contentDescriptionStartsWith, String? contentDescriptionContains, String? text, String? textStartsWith, String? textContains, String? resourceName, int? instance})
Creates a new AndroidSelector.

Properties

android → AndroidSelector
Returns the Android-specific selector.
no setteroverride
applicationPackage → String?
finalinherited
className → String?
finalinherited
contentDescription → String?
finalinherited
contentDescriptionContains → String?
finalinherited
contentDescriptionStartsWith → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
instance → int?
finalinherited
ios → IOSSelector
Returns the iOS-specific selector.
no setteroverride
isCheckable → bool?
finalinherited
isChecked → bool?
finalinherited
isClickable → bool?
finalinherited
isEnabled → bool?
finalinherited
isFocusable → bool?
finalinherited
isFocused → bool?
finalinherited
isLongClickable → bool?
finalinherited
isScrollable → bool?
finalinherited
isSelected → bool?
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
resourceName → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
text → String?
finalinherited
textContains → String?
finalinherited
textStartsWith → String?
finalinherited
web → WebSelector
Returns the Web-specific selector.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited