AppleApp enum

Inheritance
Available extensions

Values

appStore → const AppleApp
const AppleApp('com.apple.AppStore')
appleStore → const AppleApp
const AppleApp('com.apple.store.Jolly')
barcodeScanner → const AppleApp
const AppleApp('com.apple.BarcodeScanner')
books → const AppleApp
const AppleApp('com.apple.iBooks')
calculator → const AppleApp
const AppleApp('com.apple.calculator')
calendar → const AppleApp
const AppleApp('com.apple.mobilecal')
camera → const AppleApp
const AppleApp('com.apple.camera')
clips → const AppleApp
const AppleApp('com.apple.clips')
clock → const AppleApp
const AppleApp('com.apple.mobiletimer')
compass → const AppleApp
const AppleApp('com.apple.compass')
contacts → const AppleApp
const AppleApp('com.apple.MobileAddressBook')
developer → const AppleApp
const AppleApp('developer.apple.wwdc-Release')
faceTime → const AppleApp
const AppleApp('com.apple.facetime')
files → const AppleApp
const AppleApp('com.apple.DocumentsApp')
findMy → const AppleApp
const AppleApp('com.apple.findmy')
fitness → const AppleApp
const AppleApp('com.apple.Fitness')
freeform → const AppleApp
const AppleApp('com.apple.freeform')
garageBand → const AppleApp
const AppleApp('com.apple.mobilegarageband')
health → const AppleApp
const AppleApp('com.apple.Health')
home → const AppleApp
const AppleApp('com.apple.Home')
iCloudDrive → const AppleApp
const AppleApp('com.apple.iCloudDriveApp')
imagePlayground → const AppleApp
const AppleApp('com.apple.GenerativePlaygroundApp')
iMovie → const AppleApp
const AppleApp('com.apple.iMovie')
invites → const AppleApp
const AppleApp('com.apple.rsvp')
iTunesStore → const AppleApp
const AppleApp('com.apple.MobileStore')
journal → const AppleApp
const AppleApp('com.apple.journal')
keynote → const AppleApp
const AppleApp('com.apple.Keynote')
magnifier → const AppleApp
const AppleApp('com.apple.Magnifier')
mail → const AppleApp
const AppleApp('com.apple.mobilemail')
maps → const AppleApp
const AppleApp('com.apple.Maps')
measure → const AppleApp
const AppleApp('com.apple.measure')
messages → const AppleApp
const AppleApp('com.apple.MobileSMS')
music → const AppleApp
const AppleApp('com.apple.Music')
news → const AppleApp
const AppleApp('com.apple.news')
notes → const AppleApp
const AppleApp('com.apple.mobilenotes')
numbers → const AppleApp
const AppleApp('com.apple.Numbers')
pages → const AppleApp
const AppleApp('com.apple.Pages')
passwords → const AppleApp
const AppleApp('com.apple.Passwords')
phone → const AppleApp
const AppleApp('com.apple.mobilephone')
photoBooth → const AppleApp
const AppleApp('com.apple.Photo-Booth')
photos → const AppleApp
const AppleApp('com.apple.mobileslideshow')
podcasts → const AppleApp
const AppleApp('com.apple.podcasts')
reminders → const AppleApp
const AppleApp('com.apple.reminders')
safari → const AppleApp
const AppleApp('com.apple.mobilesafari')
settings → const AppleApp
const AppleApp('com.apple.Preferences')
shortcuts → const AppleApp
const AppleApp('com.apple.shortcuts')
stocks → const AppleApp
const AppleApp('com.apple.stocks')
swiftPlaygrounds → const AppleApp
const AppleApp('com.apple.Playgrounds')
tips → const AppleApp
const AppleApp('com.apple.tips')
translate → const AppleApp
const AppleApp('com.apple.Translate')
tv → const AppleApp
const AppleApp('com.apple.tv')
voiceMemos → const AppleApp
const AppleApp('com.apple.VoiceMemos')
wallet → const AppleApp
const AppleApp('com.apple.Passbook')
watch → const AppleApp
const AppleApp('com.apple.Bridge')
weather → const AppleApp
const AppleApp('com.apple.weather')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AppleApp>
A constant List of the values in this enum, in order of their declaration.