initialize method

Future<void> initialize()

Initializes the native automator.

This is a no-op — native UIA/AT-SPI2 initialization happens lazily on the first method channel call. We cannot call the channel here because the Flutter binding may not be initialized yet.

Implementation

Future<void> initialize() async {
  config.logger('initialize() - deferred to first native call');
}