DesktopAutomatorConfig class

Configuration for DesktopAutomator.

Constructors

DesktopAutomatorConfig({Duration findTimeout = const Duration(seconds: 10), void logger(String) = _defaultLogger})
Creates a new DesktopAutomatorConfig.
const

Properties

findTimeout Duration
Timeout for finding native UI elements.
final
hashCode int
The hash code for this object.
no setterinherited
logger → void Function(String)
Logger function for debug output.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited