GetNativeViewsResult class

This class represents the result of NativeAutomator.getNativeViews.

Constructors

GetNativeViewsResult({required List<AndroidNativeView> androidViews, required List<IOSNativeView> iosViews})
Creates a new GetNativeViewsResult.
const

Properties

androidViews → List<AndroidNativeView>
List of Android native views.
final
hashCode → int
The hash code for this object.
no setterinherited
iosViews → List<IOSNativeView>
List of iOS native views.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited