GoogleApp enum

Inheritance
Available extensions

Values

calculator → const GoogleApp
const GoogleApp('com.google.android.calculator')
calendar → const GoogleApp
const GoogleApp('com.google.android.calendar')
chrome → const GoogleApp
const GoogleApp('com.android.chrome')
drive → const GoogleApp
const GoogleApp('com.google.android.apps.docs')
gmail → const GoogleApp
const GoogleApp('com.google.android.gm')
maps → const GoogleApp
const GoogleApp('com.google.android.apps.maps')
photos → const GoogleApp
const GoogleApp('com.google.android.apps.photos')
playStore → const GoogleApp
const GoogleApp('com.android.vending')
settings → const GoogleApp
const GoogleApp('com.android.settings')
youtube → const GoogleApp
const GoogleApp('com.google.android.youtube')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GoogleApp>
A constant List of the values in this enum, in order of their declaration.