doubleTap abstract method

Future<void> doubleTap(
  1. IOSSelector selector, {
  2. String? appId,
  3. Duration? timeout,
})

Double taps on the native view specified by selector.

It waits for the view to become visible for timeout duration. If timeout is not specified, it utilizes the IOSAutomatorConfig.findTimeout duration from the configuration. If the native view is not found, an exception is thrown.

Implementation

Future<void> doubleTap(
  IOSSelector selector, {
  String? appId,
  Duration? timeout,
});