enterText abstract method
Future<void>
enterText(
- IOSSelector selector, {
- required String text,
- String? appId,
- KeyboardBehavior? keyboardBehavior,
- Duration? timeout,
- Offset? tapLocation,
Enters text to the native view specified by selector.
If the text field isn't immediately visible, this method waits for the
view to become visible. It prioritizes the timeout duration provided
in the method call. If timeout is not specified, it utilizes the
IOSAutomatorConfig.findTimeout duration from the configuration.
The native view specified by selector must be:
- TextField or SecureTextField on iOS
See also:
- enterTextByIndex, which is less flexible but also less verbose
Implementation
Future<void> enterText(
IOSSelector selector, {
required String text,
String? appId,
KeyboardBehavior? keyboardBehavior,
Duration? timeout,
Offset? tapLocation,
});