getNativeViews abstract method

Future<IOSGetNativeViewsResponse> getNativeViews(
  1. IOSSelector? selector, {
  2. List<String>? iosInstalledApps,
  3. String? appId,
})

Returns a list of currently visible native UI controls, specified by selector, which are currently visible on screen.

If selector is null, returns the whole native UI tree.

Implementation

Future<IOSGetNativeViewsResponse> getNativeViews(
  IOSSelector? selector, {
  List<String>? iosInstalledApps,
  String? appId,
});