grantPermissionWhenInUse abstract method

Future<void> grantPermissionWhenInUse()
inherited

Grants the permission that the currently visible native permission request dialog is asking for.

Throws if no permission request dialog is present.

See also:

  • grantPermissionOnlyThisTime and denyPermission

  • isPermissionDialogVisible, which should guard calls to this method

  • selectFineLocation and selectCoarseLocation, which works only for location permission request dialogs

Implementation

Future<void> grantPermissionWhenInUse();