openQuickSettings abstract method
Opens the quick settings shade on Android and Control Center on iOS.
Doesn't work on iOS Simulator because Control Center is not available there.
See also:
- developer.android.com/reference/androidx/test/uiautomator/UiDevice#openquicksettings, which is used on Android
Implementation
Future<void> openQuickSettings();