stopMockLocation abstract method
Stop mock location
Stops the mock location updates that were started by setMockLocation.
Implementation
Future<void> stopMockLocation();
Stop mock location
Stops the mock location updates that were started by setMockLocation.
Future<void> stopMockLocation();