swipe abstract method
Swipes from from to to.
from and to must be in the inclusive 0-1 range.
Implementation
Future<void> swipe({
required Offset from,
required Offset to,
String? appId,
bool enablePatrolLog = true,
});
Swipes from from to to.
from and to must be in the inclusive 0-1 range.
Future<void> swipe({
required Offset from,
required Offset to,
String? appId,
bool enablePatrolLog = true,
});