tapBackToPreviousAppButton abstract method
Taps on the iOS "back to previous app" breadcrumb button.
This button is visible in the status bar after opening another app and
has identifier breadcrumb with button trait.
If the breadcrumb is not visible immediately, this method waits for the
button to become visible for timeout duration. If timeout is not
specified, it utilizes the IOSAutomatorConfig.findTimeout duration
from the configuration.
Implementation
Future<void> tapBackToPreviousAppButton({Duration? timeout});