waitUntilVisible abstract method
Waits until the native view specified by selector becomes visible.
It waits for the view to become visible for timeout duration. If
timeout is not specified, it utilizes the
IOSAutomatorConfig.findTimeout.
Implementation
Future<void> waitUntilVisible(
IOSSelector selector, {
String? appId,
Duration? timeout,
});