IOSAutomatorConfig class

Configuration for IOSAutomator.

Inheritance

Constructors

IOSAutomatorConfig({String? iosInstalledApps, String? bundleId, String? appName, KeyboardBehavior? keyboardBehavior, String? host, String? port, Duration? connectionTimeout, Duration? findTimeout, void logger(String)?})
Creates a new IOSAutomatorConfig.
const

Properties

appName String
Name of the application under test on Android.
final
bundleId String
Package name of the application under test.
final
connectionTimeout Duration
Time after which the connection with the native automator will fail.
finalinherited
findTimeout Duration
Time to wait for native views to appear.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
host String
Host on which Patrol server instrumentation is running.
finalinherited
iosInstalledApps String
Apps installed on the iOS simulator.
final
keyboardBehavior KeyboardBehavior
How the keyboard should behave when entering text.
final
logger → void Function(String)
Called when a native action is performed.
finalinherited
port String
Port on host on which Patrol server instrumentation is running.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? host, String? port, String? packageName, String? appName, Duration? connectionTimeout, Duration? findTimeout, KeyboardBehavior? keyboardBehavior, void logger(String)?}) IOSAutomatorConfig
Creates a copy of this config but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited