iosInstalledApps property
Apps installed on the iOS simulator.
This is needed for purpose of native view inspection in the Patrol DevTools extension.
Implementation
final String iosInstalledApps;
Apps installed on the iOS simulator.
This is needed for purpose of native view inspection in the Patrol DevTools extension.
final String iosInstalledApps;