IOSSelector class

An iOS-specific selector for finding UI elements.

Implemented types

Constructors

IOSSelector({String? value, int? instance, IOSElementType? elementType, String? identifier, String? text, String? textStartsWith, String? textContains, String? label, String? labelStartsWith, String? labelContains, String? title, String? titleStartsWith, String? titleContains, bool? hasFocus, bool? isEnabled, bool? isSelected, String? placeholderValue, String? placeholderValueStartsWith, String? placeholderValueContains})
Creates a new IOSSelector.

Properties

android → AndroidSelector
Returns the Android-specific selector.
no setteroverride
elementType → IOSElementType?
finalinherited
hasFocus → bool?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
identifier → String?
finalinherited
instance → int?
finalinherited
ios → IOSSelector
Returns the iOS-specific selector.
no setteroverride
isEnabled → bool?
finalinherited
isSelected → bool?
finalinherited
label → String?
finalinherited
labelContains → String?
finalinherited
labelStartsWith → String?
finalinherited
placeholderValue → String?
finalinherited
placeholderValueContains → String?
finalinherited
placeholderValueStartsWith → String?
finalinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
text → String?
finalinherited
textContains → String?
finalinherited
textStartsWith → String?
finalinherited
title → String?
finalinherited
titleContains → String?
finalinherited
titleStartsWith → String?
finalinherited
value → String?
finalinherited
web → WebSelector
Returns the Web-specific selector.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited