openQuickSettings method

Future<void> openQuickSettings()

Opens the quick settings shade on Android and Control Center on iOS.

Doesn't work on iOS Simulator because Control Center is not available there.

See also:

Implementation

Future<void> openQuickSettings() {
  return platform.action.mobile(
    android: platform.android.openQuickSettings,
    ios: platform.ios.openQuickSettings,
  );
}