pickMultipleImagesFromGallery method
Future<void>
pickMultipleImagesFromGallery({
- required List<
int> imageIndexes, - CompoundSelector? imageSelector,
- Duration? timeout,
Pick multiple images from the gallery
This method opens the gallery and selects multiple images based on imageIndexes.
You can provide a custom selector for the images using imageSelector.
If no custom selector is provided, default selectors will be used.
The method will automatically handle the selection confirmation process.
Implementation
Future<void> pickMultipleImagesFromGallery({
required List<int> imageIndexes,
CompoundSelector? imageSelector,
Duration? timeout,
}) {
return platform.action.mobile(
android: () => platform.android.pickMultipleImagesFromGallery(
imageIndexes: imageIndexes,
imageSelector: imageSelector?.android,
timeout: timeout,
),
ios: () => platform.ios.pickMultipleImagesFromGallery(
imageIndexes: imageIndexes,
imageSelector: imageSelector?.ios,
timeout: timeout,
),
);
}