tapAt method

Future<void> tapAt(
  1. Offset location, {
  2. String? appId,
})

Taps at a given location.

location must be in the inclusive 0-1 range.

appId is only used on iOS, where native queries must be scoped to a single application. If not provided, defaults to the bundle id of the app under test.

Implementation

Future<void> tapAt(Offset location, {String? appId}) {
  return platform.action.mobile(
    android: () => platform.android.tapAt(location),
    ios: () => platform.ios.tapAt(location, appId: appId),
    desktop: () => platform.desktop.tapAt(location.dx, location.dy),
  );
}