tapOnNotificationBySelector method
Taps on the visible notification using selector.
Notification shade has to be opened first with openNotifications.
See also:
- tapOnNotificationByIndex, which is less flexible but also less verbose
Implementation
Future<void> tapOnNotificationBySelector(
CompoundSelector selector, {
Duration? timeout,
}) {
return platform.action.mobile(
android: () => platform.android.tapOnNotificationBySelector(
selector.android,
timeout: timeout,
),
ios: () => platform.ios.tapOnNotificationBySelector(
selector.ios,
timeout: timeout,
),
);
}