connectionTimeout property
Time after which the connection with the native automator will fail.
It must be longer than findTimeout.
Implementation
final Duration connectionTimeout;
Time after which the connection with the native automator will fail.
It must be longer than findTimeout.
final Duration connectionTimeout;