MobileSelector class

A mobile-specific selector for finding UI elements.

Implemented types

Constructors

MobileSelector({IOSSelector? ios, AndroidSelector? android})
Creates a new MobileSelector.

Properties

android AndroidSelector
Returns the Android-specific selector.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
ios IOSSelector
Returns the iOS-specific selector.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
web WebSelector
Returns the Web-specific selector.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited