NativeAutomator constructor

  1. @Deprecated('NativeAutomator is deprecated and will be removed in a future release. ' 'Please use PlatformAutomator instead.')
NativeAutomator({
  1. required PlatformAutomator platformAutomator,
})

Creates a new NativeAutomator.

Implementation

@Deprecated(
  'NativeAutomator is deprecated and will be removed in a future release. '
  'Please use PlatformAutomator instead.',
)
NativeAutomator({required PlatformAutomator platformAutomator})
  : _platform = platformAutomator;