closeNotifications method
Closes the notification shade.
It must be visible, otherwise the behavior is undefined.
Implementation
Future<void> closeNotifications() => _platform.mobile.closeNotifications();
Closes the notification shade.
It must be visible, otherwise the behavior is undefined.
Future<void> closeNotifications() => _platform.mobile.closeNotifications();