getNativeViews method

Future<List<NativeView>> getNativeViews(
  1. Selector? selector, {
  2. String? appId,
})

Returns a list of currently visible native UI controls, specified by selector, which are currently visible on screen.

If selector is null, returns the whole native UI tree.

Implementation

Future<List<NativeView>> getNativeViews(
  Selector? selector, {
  String? appId,
}) async {
  return _platform.action.mobile(
    android: () async => (await _platform.android.getNativeViews(
      selector?.android,
    )).roots.map(NativeView.fromAndroid).toList(),
    ios: () async => (await _platform.ios.getNativeViews(
      selector?.ios,
      appId: appId,
    )).roots.map(NativeView.fromIOS).toList(),
  );
}