pickMultipleImagesFromGallery method

Future<void> pickMultipleImagesFromGallery({
  1. required List<int> imageIndexes,
  2. Selector? imageSelector,
  3. Duration? timeout,
})

Pick multiple images from the gallery

This method opens the gallery and selects multiple images based on imageIndexes.

You can provide a custom selector for the images using imageSelector. If no custom selector is provided, default selectors will be used. The method will automatically handle the selection confirmation process.

Implementation

Future<void> pickMultipleImagesFromGallery({
  required List<int> imageIndexes,
  Selector? imageSelector,
  Duration? timeout,
}) => _platform.mobile.pickMultipleImagesFromGallery(
  imageIndexes: imageIndexes,
  imageSelector: imageSelector,
  timeout: timeout,
);