takeCameraPhoto method

Future<void> takeCameraPhoto({
  1. Selector? shutterButtonSelector,
  2. Selector? doneButtonSelector,
  3. Duration? timeout,
})

Take and confirm the photo

This method taps on the camera shutter button to take a photo, then taps on the confirmation button to accept it.

You can provide custom selectors for both the shutter and confirmation buttons using shutterButtonSelector and doneButtonSelector parameters. If no custom selectors are provided, default selectors will be used.

Implementation

Future<void> takeCameraPhoto({
  Selector? shutterButtonSelector,
  Selector? doneButtonSelector,
  Duration? timeout,
}) => _platform.mobile.takeCameraPhoto(
  shutterButtonSelector: shutterButtonSelector,
  doneButtonSelector: doneButtonSelector,
  timeout: timeout,
);