NativeAutomatorConfig class

Configuration for NativeAutomator.

Annotations
  • @Deprecated('NativeAutomatorConfig is deprecated and left only for backwards compatibility of patrolTest.' ' Do not use it in new code.')

Constructors

NativeAutomatorConfig({String? host, String? port, String? packageName, String? iosInstalledApps, String? bundleId, String? androidAppName, String? iosAppName, Duration? connectionTimeout, Duration? findTimeout, KeyboardBehavior? keyboardBehavior, void logger(String)?})
Creates a new NativeAutomatorConfig.

Properties

androidAppName String?
Name of the application under test on Android.
final
bundleId String?
Bundle identifier name of the application under test.
final
connectionTimeout Duration?
Time after which the connection with the native automator will fail.
final
findTimeout Duration?
Time to wait for native views to appear.
final
hashCode int
The hash code for this object.
no setterinherited
iosAppName String?
Name of the application under test on iOS.
final
iosInstalledApps String?
Apps installed on the iOS simulator.
final
keyboardBehavior KeyboardBehavior?
How the keyboard should behave when entering text.
final
logger → void Function(String)?
Called when a native action is performed.
final
packageName String?
Package name of the application under test.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPlatformAutomatorConfig() PlatformAutomatorConfig
Converts this configuration to a PlatformAutomatorConfig.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited