NativeAutomatorConfig constructor
- @Deprecated('NativeAutomatorConfig is deprecated and left only for backwards compatibility of patrolTest.' ' Do not use it in new code.')
Creates a new NativeAutomatorConfig.
Implementation
@Deprecated(
'NativeAutomatorConfig is deprecated and left only for backwards compatibility of patrolTest.'
' Do not use it in new code.',
)
NativeAutomatorConfig({
String? host,
String? port,
this.packageName,
this.iosInstalledApps,
this.bundleId,
this.androidAppName,
this.iosAppName,
this.connectionTimeout,
this.findTimeout,
this.keyboardBehavior,
this.logger,
}) {
if (host != null) {
throw StateError('host is not supported');
}
if (port != null) {
throw StateError('port is not supported');
}
}