at method
Returns a variant of this finder that only matches the item at the given index found by this finder.
Implementation
@override
PatrolFinder at(int index) {
return _select(
description: 'index $index',
selector: (candidates) {
if (index < 0) {
return const Iterable<Element>.empty();
}
return candidates.skip(index).take(1);
},
);
}