hitTestable method
Returns a variant of this finder that only matches elements reachable by a hit test.
The at parameter specifies the location relative to the size of the
target element where the hit test is performed.
Implementation
@override
PatrolFinder hitTestable({Alignment at = Alignment.center}) {
return PatrolFinder(
finder: finder.hitTestable(at: at),
tester: tester,
);
}