precache method
Attempts to evaluate the finder. Returns whether any elements in the tree matched the finder. If any did, then the result is cached and can be obtained from evaluate.
If this returns true, you must call evaluate before you call precache again.
Implementation
@override
// Do we still need to use deprecated method?
// ignore: deprecated_member_use
bool precache() => finder.precache();