reset method
Resets all state of this FinderBase.
Generally used between tests to reset the state of found if a finder is used across multiple tests.
Implementation
@override
void reset() => finder.reset();
Resets all state of this FinderBase.
Generally used between tests to reset the state of found if a finder is used across multiple tests.
@override
void reset() => finder.reset();