skipOffstage property

  1. @override
bool get skipOffstage
override

Whether this finder skips nodes that are offstage.

If this is true, then the elements are walked using Element.debugVisitOnstageChildren. This skips offstage children of Offstage widgets, as well as children of inactive Routes.

Implementation

@override
bool get skipOffstage => finder.skipOffstage;