PatrolIntegrationTester class

PatrolIntegrationTester extends the capabilities of finders.PatrolTester with the ability to interact with native platform features via native.

Constructors

PatrolIntegrationTester({required WidgetTester tester, required PatrolTesterConfig config, required PlatformAutomator platformAutomator})
Creates a new PatrolIntegrationTester which wraps tester.

Properties

config → PatrolTesterConfig
Global configuration of this tester.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isAndroid → bool
Whether the test is running on Android.
no setterinherited
isIOS → bool
Whether the test is running on iOS.
no setterinherited
isMacOS → bool
Whether the test is running on macOS.
no setterinherited
isWeb → bool
Whether the test is running on web.
no setterinherited
native → NativeAutomator
Shorthand for nativeAutomator.
no setter
native2 → NativeAutomator2
Shorthand for nativeAutomator2.
no setter
nativeAutomator ↔ NativeAutomator
Native automator that allows for interaction with OS the app is running on.
latefinal
nativeAutomator2 ↔ NativeAutomator2
Native automator with new Selector api that allows for interaction with OS the app is running on.
latefinal
patrolLog → PatrolLogWriter
Logs a message to the patrol log.
finalinherited
platform → PlatformAutomator
Shorthand for platformAutomator.
no setter
platformAutomator → PlatformAutomator
Platform automator that allows for interaction with the platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tester → WidgetTester
Flutter's widget tester that this PatrolTester wraps.
finalinherited

Methods

call(dynamic matching) → PatrolFinder
Returns a PatrolFinder that matches matching.
inherited
dragUntilExists({required Finder finder, required Finder view, required Offset moveStep, int maxIteration = defaultScrollMaxIteration, Duration? settleBetweenScrollsTimeout, Duration? dragDuration, SettlePolicy? settlePolicy, bool enablePatrolLog = true}) → Future<PatrolFinder>
Repeatedly drags view by moveStep until finder finds at least one existing widget.
inherited
dragUntilVisible({required Finder finder, required Finder view, required Offset moveStep, int maxIteration = defaultScrollMaxIteration, Duration? settleBetweenScrollsTimeout, Duration? dragDuration, SettlePolicy? settlePolicy, Alignment alignment = Alignment.center, bool enablePatrolLog = true}) → Future<PatrolFinder>
Repeatedly drags view by moveStep until finder finds at least one visible widget.
inherited
enterText(Finder finder, String text, {SettlePolicy? settlePolicy, Duration? visibleTimeout, Duration? settleTimeout, Alignment alignment = Alignment.center, bool enablePatrolLog = true, bool hideKeyboard = true}) → Future<void>
Waits until finder finds at least 1 visible widget and then enters text into it.
inherited
log(String message) → void
Logs a message to the patrol log.
longPress(Finder finder, {SettlePolicy? settlePolicy, Duration? visibleTimeout, Duration? settleTimeout, Alignment alignment = Alignment.center, bool enablePatrolLog = true}) → Future<void>
Waits until this finder finds at least 1 visible widget and then makes long press gesture on it.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pump([Duration? duration, EnginePhase phase = EnginePhase.sendSemanticsUpdate]) → Future<void>
See WidgetTester.pump.
inherited
pumpAndSettle({Duration duration = const Duration(milliseconds: 100), EnginePhase phase = EnginePhase.sendSemanticsUpdate, Duration? timeout}) → Future<void>
See WidgetTester.pumpAndSettle.
inherited
pumpAndTrySettle({Duration duration = const Duration(milliseconds: 100), EnginePhase phase = EnginePhase.sendSemanticsUpdate, Duration? timeout}) → Future<void>
Calls WidgetTester.pumpAndSettle but doesn't throw if it times out. It prevents the test from failing when there's e.g. an infinite animation.
inherited
pumpWidget(Widget widget, [Duration? duration, EnginePhase phase = EnginePhase.sendSemanticsUpdate]) → Future<void>
See WidgetTester.pumpWidget.
inherited
pumpWidgetAndSettle(Widget widget, {Duration? duration, EnginePhase phase = EnginePhase.sendSemanticsUpdate, Duration? timeout}) → Future<void>
Pumps widget and then calls WidgetTester.pumpAndSettle.
inherited
scrollUntilExists({required Finder finder, Finder? view, double delta = defaultScrollDelta, AxisDirection? scrollDirection, int maxScrolls = defaultScrollMaxIteration, Duration? settleBetweenScrollsTimeout, Duration? dragDuration, SettlePolicy? settlePolicy, bool enablePatrolLog = true}) → Future<PatrolFinder>
Scrolls view in its scrolling direction until this finders finds at least one existing widget.
inherited
scrollUntilVisible({required Finder finder, Finder? view, double delta = defaultScrollDelta, AxisDirection? scrollDirection, int maxScrolls = defaultScrollMaxIteration, Duration? settleBetweenScrollsTimeout, Duration? dragDuration, SettlePolicy? settlePolicy, Alignment alignment = Alignment.center, bool enablePatrolLog = true}) → Future<PatrolFinder>
Scrolls view in scrollDirection until this finders finds at least one existing widget.
inherited
tap(Finder finder, {SettlePolicy? settlePolicy, Duration? visibleTimeout, Duration? settleTimeout, Alignment alignment = Alignment.center, bool enablePatrolLog = true}) → Future<void>
Waits until this finder finds at least 1 visible widget and then taps on it.
inherited
toString() → String
A string representation of this object.
inherited
waitUntilExists(PatrolFinder finder, {Duration? timeout, bool enablePatrolLog = true}) → Future<PatrolFinder>
Waits until this finder finds at least one widget.
inherited
waitUntilVisible(Finder finder, {Duration? timeout, Alignment alignment = Alignment.center, bool enablePatrolLog = true}) → Future<PatrolFinder>
Waits until finder finds at least one visible widget.
inherited
wrapWithPatrolLog<T>({required String action, String? value, Finder? finder, required String color, required Future<T> function(), bool enablePatrolLog = true}) → Future<T>
Wraps a function with a log entry for the start and end of the function.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited