platformAutomator property
Platform automator that allows for interaction with the platform.
Implementation
final PlatformAutomator platformAutomator;
Platform automator that allows for interaction with the platform.
final PlatformAutomator platformAutomator;