PatrolTesterConfig class

Common configuration for PatrolTester and PatrolFinder.

Constructors

PatrolTesterConfig({Duration existsTimeout = const Duration(seconds: 10), Duration visibleTimeout = const Duration(seconds: 10), Duration settleTimeout = const Duration(seconds: 10), SettlePolicy settlePolicy = SettlePolicy.trySettle, Duration dragDuration = const Duration(milliseconds: 100), Duration settleBetweenScrollsTimeout = const Duration(seconds: 5), bool printLogs = false})
Creates a new PatrolTesterConfig.
const

Properties

dragDuration → Duration
Time that it takes to perform drag gesture in scrolling methods, such as PatrolTester.scrollUntilVisible.
final
existsTimeout → Duration
Time after which PatrolFinder.waitUntilExists fails if it doesn't find an existing widget.
final
hashCode → int
The hash code for this object.
no setterinherited
printLogs → bool
If true, patrol finders logs will be printed to the console.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settleBetweenScrollsTimeout → Duration
Timeout used to settle in between drag gestures in scrolling methods, such as PatrolTester.scrollUntilVisible (unless disabled by settlePolicy).
final
settlePolicy → SettlePolicy
Defines which pump method should be called after actions such as PatrolTester.tap, PatrolTester.enterText, and PatrolFinder.scrollTo.
final
settleTimeout → Duration
Time after which PatrolTester.pumpAndSettle fails.
final
visibleTimeout → Duration
Time after which PatrolFinder.waitUntilVisible fails if it doesn't find a visible widget.
final

Methods

copyWith({Duration? existsTimeout, Duration? visibleTimeout, Duration? settleTimeout, SettlePolicy? settlePolicy, Duration? dragDuration, Duration? settleBetweenScrollsTimeout, bool? printLogs}) → PatrolTesterConfig
Creates a copy of this config but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited