dragDuration property
Time that it takes to perform drag gesture in scrolling methods,
such as PatrolTester.scrollUntilVisible.
Implementation
final Duration dragDuration;
Time that it takes to perform drag gesture in scrolling methods,
such as PatrolTester.scrollUntilVisible.
final Duration dragDuration;