PatrolTimeoutException class

Thrown when some Patrol method fails to complete within the allowed time.

Inheritance

Constructors

PatrolTimeoutException({required Finder finder, required String message, required Duration duration})
Creates a new PatrolTimeoutException.

Properties

duration → Duration?
The duration that was exceeded.
finalinherited
finder → Finder
Finder which caused the exception.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
Description of the cause of the timeout.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited