PlatformAutomator class

Provides functionality to interact with the OS that the app under test is running on.

Constructors

PlatformAutomator({PlatformAutomatorConfig? config})
Creates a new PlatformAutomator.

Properties

action PlatformAction
Platform-specific action router.
final
android AndroidAutomator
Android-specific automator.
latefinal
desktop DesktopAutomator
Desktop automator for Linux and Windows.
latefinal
hashCode int
The hash code for this object.
no setterinherited
ios IOSAutomator
iOS-specific automator.
latefinal
mobile MobileAutomator
Mobile automator that works on both Android and iOS.
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
web WebAutomator
Web-specific automator.
latefinal

Methods

initialize() Future<void>
Initializes the native automator.
markPatrolAppServiceReady() Future<void>
Tells the AndroidJUnitRunner that PatrolAppService is ready to answer requests about the structure of Dart tests.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tap(CompoundSelector selector, {String? appId, Duration? timeout}) Future<void>
Taps on the native view specified by selector.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited