PlatformAutomatorConfig class

Configuration for PlatformAutomator.

Constructors

PlatformAutomatorConfig({AndroidAutomatorConfig? androidConfig, IOSAutomatorConfig? iosConfig, WebAutomatorConfig? webConfig, DesktopAutomatorConfig? desktopConfig})
Creates a new PlatformAutomatorConfig.
PlatformAutomatorConfig.defaultConfig()
Creates a new PlatformAutomatorConfig suitable for test setup.
factory
PlatformAutomatorConfig.fromOptions({String? iosInstalledApps, Duration? connectionTimeout, Duration? findTimeout, KeyboardBehavior? keyboardBehavior, String? packageName, String? bundleId, String? androidAppName, String? iosAppName, void logger(String)?})
Creates a new PlatformAutomatorConfig from individual options.
factory

Properties

androidConfig AndroidAutomatorConfig?
Configuration for Android platform.
final
androidEnabled bool
Whether Android platform is enabled.
no setter
desktopConfig DesktopAutomatorConfig?
Configuration for desktop platforms (Linux/Windows).
final
desktopEnabled bool
Whether desktop platform is enabled.
no setter
hashCode int
The hash code for this object.
no setterinherited
iosConfig IOSAutomatorConfig?
Configuration for iOS platform.
final
iosEnabled bool
Whether iOS platform is enabled.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webConfig WebAutomatorConfig?
Configuration for Web platform.
final
webEnabled bool
Whether Web platform is enabled.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited