PlatformSelector class
A selector that allows platform-specific selectors to be specified separately.
Use this when you need different selector configurations for each platform
See also:
- MobileSelector for mobile-only selectors (Android and iOS).
- Selector for cross-platform selectors with unified properties.
- Implemented types
Constructors
- PlatformSelector({IOSSelector? ios, AndroidSelector? android, WebSelector? web})
- Creates a new PlatformSelector.
Properties
- android → AndroidSelector
-
Returns the Android-specific selector.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- ios → IOSSelector
-
Returns the iOS-specific selector.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- web → WebSelector
-
Returns the Web-specific selector.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited