Selector class

A cross-platform selector for finding UI elements.

Implemented types

Constructors

Selector({String? text, String? textStartsWith, String? textContains, String? className, String? contentDescription, String? contentDescriptionStartsWith, String? contentDescriptionContains, String? resourceId, int? instance, bool? enabled, bool? focused, String? pkg})
Creates a new Selector.

Properties

android → AndroidSelector
Returns the Android-specific selector.
no setteroverride
className ↔ String?
The class name of the element.
getter/setter pair
contentDescription ↔ String?
The content description of the element.
getter/setter pair
contentDescriptionContains ↔ String?
Match content description that contains this string.
getter/setter pair
contentDescriptionStartsWith ↔ String?
Match content description that starts with this string.
getter/setter pair
enabled ↔ bool?
Whether the element is enabled.
getter/setter pair
focused ↔ bool?
Whether the element is focused.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instance ↔ int?
The instance index when multiple elements match.
getter/setter pair
ios → IOSSelector
Returns the iOS-specific selector.
no setteroverride
pkg ↔ String?
The package name of the application.
getter/setter pair
resourceId ↔ String?
The resource ID of the element.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
The exact text to match.
getter/setter pair
textContains ↔ String?
Match text that contains this string.
getter/setter pair
textStartsWith ↔ String?
Match text that starts with this string.
getter/setter pair
web → WebSelector
Returns the Web-specific selector.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited