SettlePolicy enum
Specifies how methods such as PatrolTester.tap or PatrolTester.enterText perform pumping, i.e. rendering new frames.
It's useful when dealing with situations involving finite and infinite animations.
Values
- noSettle → const SettlePolicy
-
PatrolTester.pumpis used when pumping.This renders a single frame. If some animations are currently in progress, they will move forward by a single frame.
- settle → const SettlePolicy
-
PatrolTester.pumpAndSettleis used when pumping.This keeps on rendering new frames until there are no frames pending or timeout is reached. Throws a FlutterError if timeout has been reached.
- trySettle → const SettlePolicy
-
PatrolTester.pumpAndTrySettleis used when pumping.This keeps on rendering new frames until there are no frames pending or timeout is reached. Doesn't throw an exception if timeout has been reached.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SettlePolicy> - A constant List of the values in this enum, in order of their declaration.