WaitUntilExistsTimeoutException class

Thrown when PatrolFinder did not find anything in the allowed time and timed out.

Inheritance

Constructors

WaitUntilExistsTimeoutException({required Finder finder, required Duration duration})
Creates a new WaitUntilExistsTimeoutException with finder which did not find any widget and timed out.

Properties

duration → Duration?
The duration that was exceeded.
finalinherited
finder → Finder
Finder which caused the exception.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String?
Description of the cause of the timeout.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited