Provides functionality to interact with web applications.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acceptNextDialog(
) → Future< String> - Accepts the next dialog that appears.
-
addCookie(
{required String name, required String value, String? url, String? domain, String? path, int? expires, bool? httpOnly, bool? secure, String? sameSite}) → Future< void> - Adds a cookie.
-
clearCookies(
) → Future< void> - Clears all cookies.
-
clearPermissions(
) → Future< void> - Clears all browser permissions.
-
configure(
) → Future< void> - Configures the web automator.
-
disableDarkMode(
) → Future< void> - Disables dark mode.
-
dismissNextDialog(
) → Future< String> - Dismisses the next dialog that appears.
-
enableDarkMode(
) → Future< void> - Enables dark mode.
-
enterText(
WebSelector selector, {required String text, WebSelector? iframeSelector}) → Future< void> -
Enters text to the web element specified by
selector. -
getClipboard(
) → Future< String> - Gets the clipboard content.
-
getCookies(
) → Future< List< LinkedHashMap< >Object?, Object?> > - Gets all cookies.
-
goBack(
) → Future< void> - Goes back in the browser history.
-
goForward(
) → Future< void> - Goes forward in the browser history.
-
grantPermissions(
{required List< String> permissions}) → Future<void> -
Grants the specified browser
permissions. -
initialize(
) → Future< void> - Initializes the web automator.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pressKey(
{required String key}) → Future< void> - Presses a keyboard key.
-
pressKeyCombo(
{required List< String> keys}) → Future<void> - Presses a keyboard key combination.
-
resizeWindow(
{required Size size}) → Future< void> - Resizes the browser window.
-
scrollTo(
WebSelector selector, {WebSelector? iframeSelector}) → Future< void> -
Scrolls to the web element specified by
selector. -
setClipboard(
{required String text}) → Future< void> - Sets the clipboard content.
-
tap(
WebSelector selector, {WebSelector? iframeSelector}) → Future< void> -
Taps on the web element specified by
selector. -
toString(
) → String -
A string representation of this object.
inherited
-
uploadFile(
{required List< UploadFileData> files}) → Future<void> - Uploads files.
-
verifyFileDownloads(
) → Future< List< String> > - Returns a list of all files downloaded during the single test.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited