WebAutomatorConfig class

Configuration for WebAutomator.

Constructors

WebAutomatorConfig({void logger(String)?})
Creates a new WebAutomatorConfig.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
logger → void Function(String)
Called when a web action is performed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited