denyPermission abstract method
Denies the permission that the currently visible native permission request dialog is asking for.
Throws if no permission request dialog is present.
See also:
-
grantPermissionWhenInUseandgrantPermissionOnlyThisTime -
isPermissionDialogVisible, which should guard calls to this method -
selectFineLocationandselectCoarseLocation, which works only for location permission request dialogs
Implementation
Future<void> denyPermission();