CompoundSelector class abstract interface

A selector that can be used across platforms.

Usage:

  • Use Selector when the same properties work across all platforms.
  • Use PlatformSelector when each platform needs a different selector.
  • Use MobileSelector when you only need Android and iOS selectors.
Implementers

Properties

android AndroidSelector
Returns the Android-specific selector.
no setter
hashCode int
The hash code for this object.
no setterinherited
ios IOSSelector
Returns the iOS-specific selector.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
web WebSelector
Returns the Web-specific selector.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited