pullToRefresh abstract method
Simulates pull-to-refresh gesture.
It swipes from from to to.
from and to must be in the inclusive 0-1 range.
The default values simulate a typical pull-to-refresh gesture:
from: Center of the screen (0.5, 0.5)to: Bottom center of the screen (0.5, 0.9) You can override these if scrollable content is not at the center of the screen or if the direction of the gesture is different.
Implementation
Future<void> pullToRefresh({
Offset from = const Offset(0.5, 0.5),
Offset to = const Offset(0.5, 0.9),
});