IOSElementType enum

Inheritance
Available extensions

Values

any → const IOSElementType
const IOSElementType('any')
other → const IOSElementType
const IOSElementType('other')
application → const IOSElementType
const IOSElementType('application')
group → const IOSElementType
const IOSElementType('group')
window → const IOSElementType
const IOSElementType('window')
sheet → const IOSElementType
const IOSElementType('sheet')
drawer → const IOSElementType
const IOSElementType('drawer')
alert → const IOSElementType
const IOSElementType('alert')
dialog → const IOSElementType
const IOSElementType('dialog')
button → const IOSElementType
const IOSElementType('button')
radioButton → const IOSElementType
const IOSElementType('radioButton')
radioGroup → const IOSElementType
const IOSElementType('radioGroup')
checkBox → const IOSElementType
const IOSElementType('checkBox')
disclosureTriangle → const IOSElementType
const IOSElementType('disclosureTriangle')
popUpButton → const IOSElementType
const IOSElementType('popUpButton')
comboBox → const IOSElementType
const IOSElementType('comboBox')
const IOSElementType('menuButton')
toolbarButton → const IOSElementType
const IOSElementType('toolbarButton')
popover → const IOSElementType
const IOSElementType('popover')
keyboard → const IOSElementType
const IOSElementType('keyboard')
key → const IOSElementType
const IOSElementType('key')
const IOSElementType('navigationBar')
tabBar → const IOSElementType
const IOSElementType('tabBar')
tabGroup → const IOSElementType
const IOSElementType('tabGroup')
toolbar → const IOSElementType
const IOSElementType('toolbar')
statusBar → const IOSElementType
const IOSElementType('statusBar')
table → const IOSElementType
const IOSElementType('table')
tableRow → const IOSElementType
const IOSElementType('tableRow')
tableColumn → const IOSElementType
const IOSElementType('tableColumn')
outline → const IOSElementType
const IOSElementType('outline')
outlineRow → const IOSElementType
const IOSElementType('outlineRow')
browser → const IOSElementType
const IOSElementType('browser')
collectionView → const IOSElementType
const IOSElementType('collectionView')
slider → const IOSElementType
const IOSElementType('slider')
pageIndicator → const IOSElementType
const IOSElementType('pageIndicator')
progressIndicator → const IOSElementType
const IOSElementType('progressIndicator')
activityIndicator → const IOSElementType
const IOSElementType('activityIndicator')
segmentedControl → const IOSElementType
const IOSElementType('segmentedControl')
picker → const IOSElementType
const IOSElementType('picker')
pickerWheel → const IOSElementType
const IOSElementType('pickerWheel')
switch_ → const IOSElementType
const IOSElementType('switch_')
toggle → const IOSElementType
const IOSElementType('toggle')
const IOSElementType('link')
image → const IOSElementType
const IOSElementType('image')
icon → const IOSElementType
const IOSElementType('icon')
searchField → const IOSElementType
const IOSElementType('searchField')
scrollView → const IOSElementType
const IOSElementType('scrollView')
scrollBar → const IOSElementType
const IOSElementType('scrollBar')
staticText → const IOSElementType
const IOSElementType('staticText')
textField → const IOSElementType
const IOSElementType('textField')
secureTextField → const IOSElementType
const IOSElementType('secureTextField')
datePicker → const IOSElementType
const IOSElementType('datePicker')
textView → const IOSElementType
const IOSElementType('textView')
const IOSElementType('menu')
const IOSElementType('menuItem')
const IOSElementType('menuBar')
const IOSElementType('menuBarItem')
map → const IOSElementType
const IOSElementType('map')
webView → const IOSElementType
const IOSElementType('webView')
incrementArrow → const IOSElementType
const IOSElementType('incrementArrow')
decrementArrow → const IOSElementType
const IOSElementType('decrementArrow')
timeline → const IOSElementType
const IOSElementType('timeline')
ratingIndicator → const IOSElementType
const IOSElementType('ratingIndicator')
valueIndicator → const IOSElementType
const IOSElementType('valueIndicator')
splitGroup → const IOSElementType
const IOSElementType('splitGroup')
splitter → const IOSElementType
const IOSElementType('splitter')
relevanceIndicator → const IOSElementType
const IOSElementType('relevanceIndicator')
colorWell → const IOSElementType
const IOSElementType('colorWell')
helpTag → const IOSElementType
const IOSElementType('helpTag')
matte → const IOSElementType
const IOSElementType('matte')
dockItem → const IOSElementType
const IOSElementType('dockItem')
ruler → const IOSElementType
const IOSElementType('ruler')
rulerMarker → const IOSElementType
const IOSElementType('rulerMarker')
grid → const IOSElementType
const IOSElementType('grid')
levelIndicator → const IOSElementType
const IOSElementType('levelIndicator')
cell → const IOSElementType
const IOSElementType('cell')
layoutArea → const IOSElementType
const IOSElementType('layoutArea')
layoutItem → const IOSElementType
const IOSElementType('layoutItem')
handle → const IOSElementType
const IOSElementType('handle')
stepper → const IOSElementType
const IOSElementType('stepper')
tab → const IOSElementType
const IOSElementType('tab')
touchBar → const IOSElementType
const IOSElementType('touchBar')
statusItem → const IOSElementType
const IOSElementType('statusItem')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IOSElementType>
A constant List of the values in this enum, in order of their declaration.