IOSNativeView class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
IOSNativeView({required List<
IOSNativeView> children, required IOSElementType elementType, required String identifier, required String label, required String title, required bool hasFocus, required bool isEnabled, required bool isSelected, required Rectangle frame, String? accessibilityLabel, String? placeholderValue, String? value, String? bundleId}) -
IOSNativeView.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accessibilityLabel → String?
-
final
- bundleId → String?
-
final
-
children
→ List<
IOSNativeView> -
final
- elementType → IOSElementType
-
final
- frame → Rectangle
-
final
- hasFocus → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- isEnabled → bool
-
final
- isSelected → bool
-
final
- label → String
-
final
- placeholderValue → String?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited - title → String
-
final
- value → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited