MobileAutomatorConfig class
Configuration for MobileAutomator.
- Implementers
Constructors
- MobileAutomatorConfig({String? host, String? port, Duration? connectionTimeout, Duration? findTimeout, void logger(String)?})
-
Creates a new MobileAutomatorConfig.
const
Properties
- connectionTimeout → Duration
-
Time after which the connection with the native automator will fail.
final
- findTimeout → Duration
-
Time to wait for native views to appear.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
Host on which Patrol server instrumentation is running.
final
- logger → void Function(String)
-
Called when a native action is performed.
final
- port → String
-
Port on host on which Patrol server instrumentation is running.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited