NativeAutomator constructor
- @Deprecated('NativeAutomator is deprecated and will be removed in a future release. ' 'Please use PlatformAutomator instead.')
- required PlatformAutomator platformAutomator,
Creates a new NativeAutomator.
Implementation
@Deprecated(
'NativeAutomator is deprecated and will be removed in a future release. '
'Please use PlatformAutomator instead.',
)
NativeAutomator({required PlatformAutomator platformAutomator})
: _platform = platformAutomator;