NativeAutomator2 constructor
- @Deprecated('NativeAutomator2 is deprecated and will be removed in a future release. ' 'Please use PlatformAutomator instead.')
- required PlatformAutomator platformAutomator,
Creates a new NativeAutomator2.
Implementation
@Deprecated(
'NativeAutomator2 is deprecated and will be removed in a future release. '
'Please use PlatformAutomator instead.',
)
NativeAutomator2({required PlatformAutomator platformAutomator})
: _platform = platformAutomator;