NativeAutomatorConfig constructor

  1. @Deprecated('NativeAutomatorConfig is deprecated and left only for backwards compatibility of patrolTest.' ' Do not use it in new code.')
NativeAutomatorConfig({
  1. String? host,
  2. String? port,
  3. String? packageName,
  4. String? iosInstalledApps,
  5. String? bundleId,
  6. String? androidAppName,
  7. String? iosAppName,
  8. Duration? connectionTimeout,
  9. Duration? findTimeout,
  10. KeyboardBehavior? keyboardBehavior,
  11. void logger(
    1. String
    )?,
})

Creates a new NativeAutomatorConfig.

Implementation

@Deprecated(
  'NativeAutomatorConfig is deprecated and left only for backwards compatibility of patrolTest.'
  ' Do not use it in new code.',
)
NativeAutomatorConfig({
  String? host,
  String? port,
  this.packageName,
  this.iosInstalledApps,
  this.bundleId,
  this.androidAppName,
  this.iosAppName,
  this.connectionTimeout,
  this.findTimeout,
  this.keyboardBehavior,
  this.logger,
}) {
  if (host != null) {
    throw StateError('host is not supported');
  }
  if (port != null) {
    throw StateError('port is not supported');
  }
}