reportExceptionNoticed method
Called when the framework catches an exception, even if that exception is being handled by takeException.
This is called when there is no pending exception; if multiple exceptions are thrown and takeException isn't used, then subsequent exceptions are logged to the console regardless (and the test will fail).
Implementation
@override
void reportExceptionNoticed(FlutterErrorDetails exception) {
// This override is copied from IntegrationTestWidgetsFlutterBinding. It may
// be not needed.
//
// See: https://github.com/flutter/flutter/issues/81534
}