visible property
bool
get
visible
Returns true if this finder finds at least 1 visible widget.
Will call isVisibleAt with Alignment.center
In case this returns false and you are sure that the widget is visible, try calling isVisibleAt with a different Alignment parameter.
Implementation
bool get visible => isVisibleAt();