markPatrolAppServiceReady method

Future<void> markPatrolAppServiceReady()

Tells the AndroidJUnitRunner that PatrolAppService is ready to answer requests about the structure of Dart tests.

Implementation

Future<void> markPatrolAppServiceReady() async {
  await action.maybe(
    android: () async => {await android.markPatrolAppServiceReady()},
    ios: () async => {await ios.markPatrolAppServiceReady()},
    // TODO: Use MacOSAutomator when such class will be implemented
    // For now we reuse the IOSAutomator for native communication on MacOS
    // The reason is that the only native interaction on MacOS is marking the app service ready
    macos: () async => {await ios.markPatrolAppServiceReady()},
    desktop: () async => {await desktop.markPatrolAppServiceReady()},
  );
}