UploadFileData class
Represents a file to be uploaded via the web automator.
- Annotations
-
- @JsonSerializable.new()
Constructors
-
UploadFileData({required String name, required List<
int> content, String mimeType = 'application/octet-stream'}) - Creates a file upload data object.
Properties
-
content
→ List<
int> -
The file content as bytes
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → String
-
The MIME type of the file (e.g., 'text/plain', 'image/png')
final
- name → String
-
The name of the file (e.g., 'example.txt')
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this object to JSON, encoding the content as base64.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited