WebSelector class
A Web-specific selector for finding UI elements.
- Implemented types
Constructors
- WebSelector({String? role, String? label, String? placeholder, String? text, String? altText, String? title, String? testId, String? cssOrXpath})
- Creates a new WebSelector.
Properties
- altText → String?
-
The alt text of the element.
finalinherited
- android → AndroidSelector
-
Returns the Android-specific selector.
no setteroverride
- cssOrXpath → String?
-
A CSS selector or XPath expression. Can start with
css=orxpath=to force a specific selector type.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- ios → IOSSelector
-
Returns the iOS-specific selector.
no setteroverride
- label → String?
-
The label of the element.
finalinherited
- placeholder → String?
-
The placeholder text of the element.
finalinherited
- role → String?
-
The ARIA role of the element.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- testId → String?
-
The test ID of the element.
finalinherited
- text → String?
-
The text content of the element.
finalinherited
- title → String?
-
The title of the element.
finalinherited
- web → WebSelector
-
Returns the Web-specific selector.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts this selector to JSON.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited